@@ -2,7 +2,7 @@
  *  Copyright 2004-2005 Paul Querna
  *  Copyright 2008 Nikos Mavrogiannopoulos
  *  Copyright 2011 Dash Shendy
- *  Copyright 2015-2018 Fiona Klute
+ *  Copyright 2015-2020 Fiona Klute
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -168,12 +168,6 @@ static int socache_store_session(void *baton, gnutls_datum_t key,
 
 
 
-/** 8K is the maximum size accepted when receiving OCSP responses,
- * sessions cache entries should be much smaller. The buffer is
- * reallocated to actual size after fetching, so memory waste is
- * minimal and temporary. */
-#define SOCACHE_FETCH_BUF_SIZE (8 * 1024)
-
 apr_status_t mgs_cache_fetch(mgs_cache_t cache, server_rec *server,
                              gnutls_datum_t key, gnutls_datum_t *output,
                              apr_pool_t *pool)
@@ -239,10 +233,10 @@ static gnutls_datum_t socache_fetch_session(void *baton, gnutls_datum_t key)
     if (mgs_session_id2dbm(ctxt->c, key.data, key.size, &dbmkey) < 0)
         return data;
 
-    data.data = gnutls_malloc(SOCACHE_FETCH_BUF_SIZE);
+    data.data = gnutls_malloc(MGS_SESSION_FETCH_BUF_SIZE);
     if (data.data == NULL)
         return data;
-    data.size = SOCACHE_FETCH_BUF_SIZE;
+    data.size = MGS_SESSION_FETCH_BUF_SIZE;
 
     apr_status_t rv = mgs_cache_fetch(ctxt->sc->cache, ctxt->c->base_server,
                                       dbmkey, &data, ctxt->c->pool);
@@ -274,6 +268,34 @@ static gnutls_datum_t socache_fetch_session(void *baton, gnutls_datum_t key)
 
 
 
+apr_status_t mgs_cache_delete(mgs_cache_t cache, server_rec *server,
+                              gnutls_datum_t key, apr_pool_t *pool)
+{
+    apr_pool_t *spool;
+    apr_pool_create(&spool, pool);
+
+    if (cache->prov->flags & AP_SOCACHE_FLAG_NOTMPSAFE)
+        apr_global_mutex_lock(cache->mutex);
+    apr_status_t rv = cache->prov->remove(cache->socache, server,
+                                          key.data, key.size,
+                                          spool);
+    if (cache->prov->flags & AP_SOCACHE_FLAG_NOTMPSAFE)
+        apr_global_mutex_unlock(cache->mutex);
+
+    if (rv != APR_SUCCESS)
+        ap_log_error(APLOG_MARK, APLOG_NOTICE, rv, server,
+                     "error deleting from cache '%s:%s'",
+                     cache->prov->name, cache->config);
+    else
+        ap_log_error(APLOG_MARK, APLOG_TRACE1, rv, server,
+                     "deleted entry from cache '%s:%s'",
+                     cache->prov->name, cache->config);
+    apr_pool_destroy(spool);
+    return rv;
+}
+
+
+
 /**
  * Remove function for the GnuTLS session cache, see
  * gnutls_db_set_remove_function().
@@ -287,29 +309,18 @@ static gnutls_datum_t socache_fetch_session(void *baton, gnutls_datum_t key)
  */
 static int socache_delete_session(void *baton, gnutls_datum_t key)
 {
-    gnutls_datum_t tmpkey;
+    gnutls_datum_t dbmkey;
     mgs_handle_t *ctxt = baton;
 
-    if (mgs_session_id2dbm(ctxt->c, key.data, key.size, &tmpkey) < 0)
+    if (mgs_session_id2dbm(ctxt->c, key.data, key.size, &dbmkey) < 0)
         return -1;
 
-    if (ctxt->sc->cache->prov->flags & AP_SOCACHE_FLAG_NOTMPSAFE)
-        apr_global_mutex_lock(ctxt->sc->cache->mutex);
-    apr_status_t rv = ctxt->sc->cache->prov->remove(ctxt->sc->cache->socache,
-                                                    ctxt->c->base_server,
-                                                    key.data, key.size,
-                                                    ctxt->c->pool);
-    if (ctxt->sc->cache->prov->flags & AP_SOCACHE_FLAG_NOTMPSAFE)
-        apr_global_mutex_unlock(ctxt->sc->cache->mutex);
-
-    if (rv != APR_SUCCESS) {
-        ap_log_error(APLOG_MARK, APLOG_NOTICE, rv,
-                     ctxt->c->base_server,
-                     "error deleting from cache '%s:%s'",
-                     ctxt->sc->cache->prov->name, ctxt->sc->cache->config);
+    apr_status_t rv = mgs_cache_delete(ctxt->sc->cache, ctxt->c->base_server,
+                                       dbmkey, ctxt->c->pool);
+    if (rv != APR_SUCCESS)
         return -1;
-    }
-    return 0;
+    else
+        return 0;
 }
 
 
