@@ -1,7 +1,7 @@
 /*
  *  Copyright 2004-2005 Paul Querna
  *  Copyright 2014 Nikos Mavrogiannopoulos
- *  Copyright 2015-2018 Fiona Klute
+ *  Copyright 2015-2020 Fiona Klute
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -33,6 +33,12 @@
  * `Mutex` directive */
 #define MGS_CACHE_MUTEX_NAME "gnutls-cache"
 
+/** 8K is the maximum size accepted when receiving OCSP responses,
+ * sessions cache entries should be much smaller. The buffer is
+ * reallocated to actual size after fetching, so memory waste is
+ * minimal and temporary. */
+#define MGS_SESSION_FETCH_BUF_SIZE (8 * 1024)
+
 /**
  * Configure a cache instance
  *
@@ -148,6 +154,22 @@ apr_status_t mgs_cache_fetch(mgs_cache_t cache, server_rec *server,
                              gnutls_datum_t key, gnutls_datum_t *output,
                              apr_pool_t *pool);
 
+/**
+ * Delete an item from the mod_gnutls object caches.
+ *
+ * @param cache the cache to delete from
+ *
+ * @param server server context for the request
+ *
+ * @param key key for the cache entry to be deleted
+ *
+ * @param pool pool to allocate temporary memory from
+ *
+ * @return APR status or error value
+ */
+apr_status_t mgs_cache_delete(mgs_cache_t cache, server_rec *server,
+                              gnutls_datum_t key, apr_pool_t *pool);
+
 /**
  * Internal cache configuration structure
  */
