@@ -160,8 +160,9 @@ int mgs_hook_pre_config(apr_pool_t * pconf, apr_pool_t * plog, apr_pool_t * ptem
     if (ret < 0)
     {
         ap_log_perror(APLOG_MARK, APLOG_EMERG, 0, plog,
-                      "gnutls_priority_init failed for default '%s': %s (%d)",
-                      MGS_DEFAULT_PRIORITY, gnutls_strerror(ret), ret);
+                      "gnutls_priority_init failed for default '"
+                      MGS_DEFAULT_PRIORITY "': %s (%d)",
+                      gnutls_strerror(ret), ret);
         return DONE;
     }
 
@@ -575,7 +576,6 @@ int mgs_hook_post_config(apr_pool_t *pconf,
 {
     int rv;
     server_rec *s;
-    mgs_srvconf_rec *sc;
     mgs_srvconf_rec *sc_base;
 
     s = base_server;
@@ -644,7 +644,8 @@ int mgs_hook_post_config(apr_pool_t *pconf,
 
     for (s = base_server; s; s = s->next)
     {
-        sc = (mgs_srvconf_rec *) ap_get_module_config(s->module_config, &gnutls_module);
+        mgs_srvconf_rec *sc = (mgs_srvconf_rec *)
+            ap_get_module_config(s->module_config, &gnutls_module);
         sc->s = s;
         sc->cache_enable = sc_base->cache_enable;
         sc->cache = sc_base->cache;
@@ -721,9 +722,8 @@ int mgs_hook_post_config(apr_pool_t *pconf,
         if (sc->priorities == NULL && sc->enabled == GNUTLS_ENABLED_TRUE) {
             ap_log_error(APLOG_MARK, APLOG_INFO, 0, s,
                          "No GnuTLSPriorities directive for host '%s:%d', "
-                         "using default '%s'.",
-                         s->server_hostname, s->addrs->host_port,
-                         MGS_DEFAULT_PRIORITY);
+                         "using default '" MGS_DEFAULT_PRIORITY "'.",
+                         s->server_hostname, s->addrs->host_port);
             sc->priorities = mgs_get_default_prio();
         }
 
@@ -941,13 +941,10 @@ int check_server_aliases(vhost_cb_rec *x, server_rec * s, mgs_srvconf_rec *tsc)
 
 static int vhost_cb(void *baton, conn_rec *conn, server_rec * s)
 {
-    mgs_srvconf_rec *tsc;
     vhost_cb_rec *x = baton;
-    int ret;
-
+    mgs_srvconf_rec *tsc = (mgs_srvconf_rec *)
+        ap_get_module_config(s->module_config, &gnutls_module);
     _gnutls_log(debug_log_fp, "%s: %d\n", __func__, __LINE__);
-    tsc = (mgs_srvconf_rec *) ap_get_module_config(s->module_config,
-            &gnutls_module);
 
     if (tsc->enabled != GNUTLS_ENABLED_TRUE) {
         return 0;
@@ -956,7 +953,8 @@ static int vhost_cb(void *baton, conn_rec *conn, server_rec * s)
     if (tsc->certs_x509_chain_num > 0) {
         /* this check is there to warn administrator of any missing hostname
          * in the certificate. */
-        ret = gnutls_x509_crt_check_hostname(tsc->certs_x509_crt_chain[0], s->server_hostname);
+        int ret = gnutls_x509_crt_check_hostname(tsc->certs_x509_crt_chain[0],
+                                                 s->server_hostname);
         if (0 == ret)
             ap_log_cerror(APLOG_MARK, APLOG_DEBUG, 0, conn,
                           "GnuTLS: the certificate doesn't match requested "
@@ -1101,7 +1099,16 @@ static apr_status_t cleanup_gnutls_session(void *data)
 
     /* check if session needs closing */
     mgs_handle_t *ctxt = (mgs_handle_t *) data;
-    if (ctxt->session != NULL)
+    if (ctxt->session == NULL)
+        return APR_SUCCESS;
+
+    if (ctxt->c->aborted)
+    {
+        ap_log_cerror(APLOG_MARK, APLOG_DEBUG, APR_SUCCESS, ctxt->c,
+                      "%s: TLS %sconnection aborted, cleaning up.",
+                      __func__, IS_PROXY_STR(ctxt));
+    }
+    else
     {
         ap_log_cerror(APLOG_MARK, APLOG_WARNING, APR_ECONNABORTED, ctxt->c,
                       "%s: connection pool cleanup in progress but %sTLS "
@@ -1113,7 +1120,7 @@ static apr_status_t cleanup_gnutls_session(void *data)
             ret = gnutls_bye(ctxt->session, GNUTLS_SHUT_WR);
         while (ret == GNUTLS_E_INTERRUPTED || ret == GNUTLS_E_AGAIN);
         if (ret != GNUTLS_E_SUCCESS)
-            ap_log_cerror(APLOG_MARK, APLOG_INFO, APR_EGENERAL, ctxt->c,
+            ap_log_cerror(APLOG_MARK, APLOG_DEBUG, APR_EGENERAL, ctxt->c,
                           "%s: error while closing TLS %sconnection: %s (%d)",
                           __func__, IS_PROXY_STR(ctxt),
                           gnutls_strerror(ret), ret);
@@ -1121,10 +1128,11 @@ static apr_status_t cleanup_gnutls_session(void *data)
             ap_log_cerror(APLOG_MARK, APLOG_DEBUG, APR_SUCCESS, ctxt->c,
                           "%s: TLS %sconnection closed.",
                           __func__, IS_PROXY_STR(ctxt));
-        /* De-Initialize Session */
-        gnutls_deinit(ctxt->session);
-        ctxt->session = NULL;
     }
+
+    /* De-Initialize Session */
+    gnutls_deinit(ctxt->session);
+    ctxt->session = NULL;
     return APR_SUCCESS;
 }
 
@@ -1607,7 +1615,6 @@ static void mgs_add_common_cert_vars(request_rec * r, gnutls_x509_crt_t cert, in
     /* export all the alternative names (DNS, RFC822 and URI) */
     for (int i = 0; !(ret < 0); i++)
     {
-        const char *san, *sanlabel;
         len = 0;
         ret = gnutls_x509_crt_get_subject_alt_name(cert, i,
                 NULL, &len,
@@ -1623,6 +1630,7 @@ static void mgs_add_common_cert_vars(request_rec * r, gnutls_x509_crt_t cert, in
                     NULL);
             tmp2[len] = 0;
 
+            const char *san, *sanlabel;
             sanlabel = apr_psprintf(r->pool, "%s%u", MGS_SIDE("_S_AN"), i);
             if (ret == GNUTLS_SAN_DNSNAME) {
                 san = apr_psprintf(r->pool, "DNSNAME:%s", tmp2);
@@ -1738,7 +1746,6 @@ static int mgs_cert_verify(request_rec * r, mgs_handle_t * ctxt) {
             char cert_pem_buf[10 * 1024];
             size_t len = sizeof (cert_pem_buf);
 
-            rv = 0;
             if (gnutls_x509_crt_export(cert.x509[0], GNUTLS_X509_FMT_PEM, cert_pem_buf, &len) >= 0) {
                 /* FIXME : put together a name from the cert we received, instead of hard-coding this value: */
                 q.peername = mgs_x509_construct_uid(r, cert.x509[0]);
