@@ -36,14 +36,6 @@ APLOG_USE_MODULE(gnutls);
  *
  */
 
-#define HTTP_ON_HTTPS_PORT \
-    "GET /" CRLF
-
-#define HTTP_ON_HTTPS_PORT_BUCKET(alloc) \
-    apr_bucket_immortal_create(HTTP_ON_HTTPS_PORT, \
-                               sizeof(HTTP_ON_HTTPS_PORT) - 1, \
-                               alloc)
-
 #define IS_PROXY_STR(c) \
     ((c->is_proxy == GNUTLS_ENABLED_TRUE) ? "proxy " : "")
 
@@ -55,35 +47,19 @@ APLOG_USE_MODULE(gnutls);
 
 
 
-static apr_status_t gnutls_io_filter_error(ap_filter_t * f,
-        apr_bucket_brigade * bb,
-        apr_status_t status) {
-    mgs_handle_t *ctxt = (mgs_handle_t *) f->ctx;
-    apr_bucket *bucket;
-
-    switch (status) {
-    case HTTP_BAD_REQUEST:
-        /* log the situation */
-        ap_log_cerror(APLOG_MARK, APLOG_INFO, 0, f->c,
-                      "GnuTLS handshake failed: HTTP spoken on HTTPS port; "
-                      "trying to send HTML error page");
-        ctxt->status = -1;
-
-        /* fake the request line */
-        bucket = HTTP_ON_HTTPS_PORT_BUCKET(f->c->bucket_alloc);
-        break;
-
-    default:
-        return status;
-    }
-
+/**
+ * Helper function, used mostly for error conditions: Insert an EOS (end
+ * of stream) bucket into the bucket brigade.
+ */
+static inline void gnutls_io_filter_eos(ap_filter_t *f,
+                                        apr_bucket_brigade *bb)
+{
+    apr_bucket *bucket = apr_bucket_eos_create(f->c->bucket_alloc);
     APR_BRIGADE_INSERT_TAIL(bb, bucket);
-    bucket = apr_bucket_eos_create(f->c->bucket_alloc);
-    APR_BRIGADE_INSERT_TAIL(bb, bucket);
-
-    return APR_SUCCESS;
 }
 
+
+
 static int char_buffer_read(mgs_char_buffer_t * buffer, char *in, int inl) {
     if (!buffer->length) {
         return 0;
@@ -126,7 +102,6 @@ static apr_status_t brigade_consume(apr_bucket_brigade * bb,
         apr_bucket *b = APR_BRIGADE_FIRST(bb);
         const char *str;
         apr_size_t str_len;
-        apr_size_t consume;
 
         /* Justin points out this is an http-ism that might
          * not fit if brigade_consume is added to APR.  Perhaps
@@ -163,9 +138,8 @@ static apr_status_t brigade_consume(apr_bucket_brigade * bb,
             block = APR_NONBLOCK_READ;
 
             /* Assure we don't overflow. */
-            consume =
-                    (str_len + actual >
-                    *len) ? *len - actual : str_len;
+            apr_size_t consume =
+                (str_len + actual > *len) ? *len - actual : str_len;
 
             memcpy(c, str, consume);
 
@@ -200,7 +174,6 @@ static apr_status_t gnutls_io_input_read(mgs_handle_t * ctxt,
 {
     apr_size_t wanted = *len;
     apr_size_t bytes = 0;
-    int rc;
 
     *len = 0;
 
@@ -244,7 +217,8 @@ static apr_status_t gnutls_io_input_read(mgs_handle_t * ctxt,
     while (1)
     {
         /* Note: The pull function sets ctxt->input_rc */
-        rc = gnutls_record_recv(ctxt->session, buf + bytes, wanted - bytes);
+        int rc = gnutls_record_recv(ctxt->session,
+                                    buf + bytes, wanted - bytes);
 
         if (rc > 0) {
             *len += rc;
@@ -279,7 +253,7 @@ static apr_status_t gnutls_io_input_read(mgs_handle_t * ctxt,
                         (rc == GNUTLS_E_AGAIN ? APR_EAGAIN : APR_EINTR);
             } else if (rc == GNUTLS_E_REHANDSHAKE) {
                 /* A client has asked for a new Hankshake. Currently, we don't do it */
-                ap_log_cerror(APLOG_MARK, APLOG_INFO,
+                ap_log_cerror(APLOG_MARK, APLOG_DEBUG,
                         ctxt->input_rc,
                         ctxt->c,
                         "GnuTLS: Error reading data. Client Requested a New Handshake."
@@ -287,7 +261,7 @@ static apr_status_t gnutls_io_input_read(mgs_handle_t * ctxt,
                         gnutls_strerror(rc));
             } else if (rc == GNUTLS_E_WARNING_ALERT_RECEIVED) {
                 rc = gnutls_alert_get(ctxt->session);
-                ap_log_cerror(APLOG_MARK, APLOG_INFO,
+                ap_log_cerror(APLOG_MARK, APLOG_DEBUG,
                         ctxt->input_rc,
                         ctxt->c,
                         "GnuTLS: Warning Alert From Client: "
@@ -295,7 +269,7 @@ static apr_status_t gnutls_io_input_read(mgs_handle_t * ctxt,
                         gnutls_alert_get_name(rc));
             } else if (rc == GNUTLS_E_FATAL_ALERT_RECEIVED) {
                 rc = gnutls_alert_get(ctxt->session);
-                ap_log_cerror(APLOG_MARK, APLOG_INFO,
+                ap_log_cerror(APLOG_MARK, APLOG_DEBUG,
                         ctxt->input_rc,
                         ctxt->c,
                         "GnuTLS: Fatal Alert From Client: "
@@ -306,13 +280,12 @@ static apr_status_t gnutls_io_input_read(mgs_handle_t * ctxt,
             } else {
                 /* Some Other Error. Report it. Die. */
                 if (gnutls_error_is_fatal(rc)) {
-                    ap_log_cerror(APLOG_MARK,
-                            APLOG_INFO,
-                            ctxt->input_rc,
-                            ctxt->c,
-                            "GnuTLS: Error reading data. (%d) '%s'",
-                            rc,
-                            gnutls_strerror(rc));
+                    ap_log_cerror(
+                        APLOG_MARK, APLOG_DEBUG,
+                        ctxt->input_rc,
+                        ctxt->c,
+                        "GnuTLS: Error reading data. (%d) '%s'",
+                        rc, gnutls_strerror(rc));
                 } else if (*len > 0) {
                     ctxt->input_rc = APR_SUCCESS;
                     break;
@@ -334,13 +307,14 @@ static apr_status_t gnutls_io_input_read(mgs_handle_t * ctxt,
 static apr_status_t gnutls_io_input_getline(mgs_handle_t * ctxt,
         char *buf, apr_size_t * len) {
     const char *pos = NULL;
-    apr_status_t status;
     apr_size_t tmplen = *len, buflen = *len, offset = 0;
 
     *len = 0;
 
-    while (tmplen > 0) {
-        status = gnutls_io_input_read(ctxt, buf + offset, &tmplen);
+    while (tmplen > 0)
+    {
+        apr_status_t status =
+            gnutls_io_input_read(ctxt, buf + offset, &tmplen);
 
         if (status != APR_SUCCESS) {
             return status;
@@ -559,9 +533,7 @@ apr_status_t mgs_filter_input(ap_filter_t * f,
     apr_size_t len = sizeof (ctxt->input_buffer);
 
     if (f->c->aborted) {
-        apr_bucket *bucket =
-                apr_bucket_eos_create(f->c->bucket_alloc);
-        APR_BRIGADE_INSERT_TAIL(bb, bucket);
+        gnutls_io_filter_eos(f, bb);
         ap_log_cerror(APLOG_MARK, APLOG_DEBUG, 0, ctxt->c,
                       "%s: %sconnection aborted",
                       __func__, IS_PROXY_STR(ctxt));
@@ -581,9 +553,7 @@ apr_status_t mgs_filter_input(ap_filter_t * f,
         ap_log_cerror(APLOG_MARK, APLOG_TRACE1, 0, ctxt->c,
                       "%s: %sconnection failed, cannot provide data!",
                       __func__, IS_PROXY_STR(ctxt));
-        apr_bucket *bucket =
-                apr_bucket_eos_create(f->c->bucket_alloc);
-        APR_BRIGADE_INSERT_TAIL(bb, bucket);
+        gnutls_io_filter_eos(f, bb);
         return APR_ECONNABORTED;
     }
 
@@ -648,11 +618,12 @@ apr_status_t mgs_filter_input(ap_filter_t * f,
             return APR_EAGAIN;
 
         /* Close TLS session and free resources on EOF,
-         * gnutls_io_filter_error will add an EOS bucket */
+         * gnutls_io_filter_eos will add an EOS bucket */
         if (APR_STATUS_IS_EOF(status))
             mgs_bye(ctxt);
 
-        return gnutls_io_filter_error(f, bb, status);
+        gnutls_io_filter_eos(f, bb);
+        return status;
     }
 
     /* Create a transient bucket out of the decrypted data. */
@@ -729,8 +700,7 @@ apr_status_t mgs_filter_output(ap_filter_t * f, apr_bucket_brigade * bb) {
              * client. By pretending we could send the request
              * mod_proxy continues its processing and sends a proper
              * "proxy error" message when there's no response to read. */
-            apr_bucket *bucket = apr_bucket_eos_create(f->c->bucket_alloc);
-            APR_BRIGADE_INSERT_TAIL(bb, bucket);
+            gnutls_io_filter_eos(f, bb);
             return APR_SUCCESS;
         }
         /* No final else here, the "ctxt->status < 0" check below will
@@ -806,7 +776,7 @@ apr_status_t mgs_filter_output(ap_filter_t * f, apr_bucket_brigade * bb) {
 
                 if (ret < 0) {
                     /* error sending output */
-                    ap_log_cerror(APLOG_MARK, APLOG_INFO, ctxt->output_rc,
+                    ap_log_cerror(APLOG_MARK, APLOG_DEBUG, ctxt->output_rc,
                                   ctxt->c,
                                   "GnuTLS: Error writing data. (%d) '%s'",
                                   ret, gnutls_strerror(ret));
@@ -986,7 +956,6 @@ ssize_t mgs_transport_read(gnutls_transport_ptr_t ptr,
                            void *buffer, size_t len)
 {
     mgs_handle_t *ctxt = ptr;
-    apr_status_t rc;
     apr_size_t in = len;
     apr_read_type_e block = ctxt->input_block;
 
@@ -1007,9 +976,9 @@ ssize_t mgs_transport_read(gnutls_transport_ptr_t ptr,
 
     if (APR_BRIGADE_EMPTY(ctxt->input_bb))
     {
-        rc = ap_get_brigade(ctxt->input_filter->next,
-                            ctxt->input_bb, AP_MODE_READBYTES,
-                            ctxt->input_block, in);
+        apr_status_t rc = ap_get_brigade(ctxt->input_filter->next,
+                                         ctxt->input_bb, AP_MODE_READBYTES,
+                                         ctxt->input_block, in);
 
         /* Not a problem, there was simply no data ready yet.
          */
