@@ -111,6 +111,7 @@ from string import Template
 from . import TestExpectationFailed
 from .http import HTTPSubprocessConnection
 
+
 class Transports(Enum):
     """Transports supported by TestConnection."""
     GNUTLS = auto()
@@ -119,6 +120,7 @@ class Transports(Enum):
     def __repr__(self):
         return f'{self.__class__.__name__!s}.{self.name}'
 
+
 class TestConnection(yaml.YAMLObject):
     """An HTTP connection in a test. It includes parameters for the
     transport, and the actions (e.g. sending requests) to take using
@@ -197,7 +199,6 @@ class TestConnection(yaml.YAMLObject):
         return conn
 
 
-
 class TestRequest(yaml.YAMLObject):
     """Test action that sends an HTTP/1.1 request.
 
@@ -213,6 +214,7 @@ class TestRequest(yaml.YAMLObject):
 
     """
     yaml_tag = '!request'
+
     def __init__(self, path, method='GET', body=None, headers=dict(),
                  expect=dict(status=200)):
         self.method = method
@@ -248,20 +250,6 @@ class TestRequest(yaml.YAMLObject):
         self.check_response(resp, body)
 
     def check_headers(self, headers):
-        """
-        >>> r1 = TestRequest(path='/test.txt',
-        ...                  expect={ 'headers': {'X-Forbidden-Header': None,
-        ...                                       'X-Required-Header': 'Hi!' }})
-        >>> r1.check_headers({ 'X-Required-Header': 'Hi!' })
-        >>> r1.check_headers({ 'X-Required-Header': 'Hello!' })
-        Traceback (most recent call last):
-        ...
-        mgstest.TestExpectationFailed: Unexpected value in header X-Required-Header: 'Hello!', expected 'Hi!'
-        >>> r1.check_headers({ 'X-Forbidden-Header': 'Hi!' })
-        Traceback (most recent call last):
-        ...
-        mgstest.TestExpectationFailed: Unexpected value in header X-Forbidden-Header: 'Hi!', expected None
-        """
         for name, expected in self.expect['headers'].items():
             value = headers.get(name)
             expected = subst_env(expected)
@@ -271,22 +259,6 @@ class TestRequest(yaml.YAMLObject):
                     f'expected {expected!r}')
 
     def check_body(self, body):
-        """
-        >>> r1 = TestRequest(path='/test.txt', method='GET', headers={}, expect={'status': 200, 'body': {'exactly': 'test\\n'}})
-        >>> r1.check_body('test\\n')
-        >>> r1.check_body('xyz\\n')
-        Traceback (most recent call last):
-        ...
-        mgstest.TestExpectationFailed: Unexpected body: 'xyz\\n' != 'test\\n'
-        >>> r2 = TestRequest(path='/test.txt', method='GET', headers={}, expect={'status': 200, 'body': {'contains': ['tes', 'est']}})
-        >>> r2.check_body('test\\n')
-        >>> r2.check_body('est\\n')
-        Traceback (most recent call last):
-        ...
-        mgstest.TestExpectationFailed: Unexpected body: 'est\\n' does not contain 'tes'
-        >>> r3 = TestRequest(path='/test.txt', method='GET', headers={}, expect={'status': 200, 'body': {'contains': 'test'}})
-        >>> r3.check_body('test\\n')
-        """
         if 'exactly' in self.expect['body'] \
            and body != self.expect['body']['exactly']:
             raise TestExpectationFailed(
@@ -297,7 +269,7 @@ class TestRequest(yaml.YAMLObject):
                 self.expect['body']['contains'] = [
                     self.expect['body']['contains']]
             for s in self.expect['body']['contains']:
-                if not s in body:
+                if s not in body:
                     raise TestExpectationFailed(
                         f'Unexpected body: {body!r} does not contain '
                         f'{s!r}')
@@ -319,13 +291,6 @@ class TestRequest(yaml.YAMLObject):
         """Returns True if running this request is expected to fail due to the
         connection being reset. That usually means the underlying TLS
         connection failed.
-
-        >>> r1 = TestRequest(path='/test.txt', method='GET', headers={}, expect={'status': 200, 'body': {'contains': 'test'}})
-        >>> r1.expects_conn_reset()
-        False
-        >>> r2 = TestRequest(path='/test.txt', method='GET', headers={}, expect={'reset': True})
-        >>> r2.expects_conn_reset()
-        True
         """
         if 'reset' in self.expect:
             return self.expect['reset']
@@ -338,7 +303,6 @@ class TestRequest(yaml.YAMLObject):
         return req
 
 
-
 class TestReq10(TestRequest):
     """Test action that sends a request using a minimal (and likely
     incomplete) HTTP/1.0 test client for the one test case that
@@ -372,7 +336,7 @@ class TestReq10(TestRequest):
                                 bufsize=0)
         try:
             outs, errs = proc.communicate(input=req, timeout=timeout)
-        except TimeoutExpired:
+        except subprocess.TimeoutExpired:
             proc.kill()
             outs, errs = proc.communicate()
 
@@ -427,7 +391,6 @@ class TestReq10(TestRequest):
             self.check_body(body)
 
 
-
 class Resume(yaml.YAMLObject):
     """Test action to close and resume the TLS session.
 
@@ -441,8 +404,9 @@ class Resume(yaml.YAMLObject):
 
     """
     yaml_tag = '!resume'
+
     def run(self, conn, command):
-        if not '--inline-commands' in command:
+        if '--inline-commands' not in command:
             raise ValueError('gnutls_params must include "inline-commands" '
                              'to use the resume action!')
         if not type(conn) is HTTPSubprocessConnection:
@@ -451,7 +415,6 @@ class Resume(yaml.YAMLObject):
         conn.sock.send(b'^resume^\n')
 
 
-
 def filter_cert_log(in_stream, out_stream):
     """Filter to stop an erroneous gnutls-cli log message.
 
@@ -505,7 +468,6 @@ def filter_cert_log(in_stream, out_stream):
     out_stream.close()
 
 
-
 def format_response(resp, body):
     """Format an http.client.HTTPResponse for logging."""
     s = f'{resp.status} {resp.reason}\n'
@@ -514,7 +476,6 @@ def format_response(resp, body):
     return s
 
 
-
 def subst_env(text):
     """Use the parameter "text" as a template, substitute with environment
     variables.
@@ -540,7 +501,6 @@ def subst_env(text):
     return t.substitute(os.environ)
 
 
-
 def run_test_conf(test_config, timeout=5.0, conn_log=None, response_log=None):
     """Load and run a test configuration.
 
