@@ -15,13 +15,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import asyncio
 import contextlib
+import itertools
 import os
-import os.path
 import subprocess
 import sys
 import tempfile
 import yaml
+from pathlib import Path
 from unittest import SkipTest
 
 import mgstest.hooks
@@ -31,7 +33,6 @@ from mgstest.services import ApacheService, TestService
 from mgstest.tests import run_test_conf
 
 
-
 def find_testdir(number, dir):
     """Find the configuration directory for a test based on its
     number. The given directory must contain exactly one directory
@@ -39,77 +40,74 @@ def find_testdir(number, dir):
     raised.
 
     """
-    with os.scandir(dir) as it:
-        found = None
-        for entry in it:
-            if entry.is_dir():
-                num = int(entry.name.split('_', maxsplit=1)[0])
-                if number == num:
-                    if found:
-                        # duplicate numbers are an error
-                        raise LookupError('Multiple directories found for '
-                                          f'test number {number}: '
-                                          f'{found.name} and {entry.name}')
-                    else:
-                        found = entry
-        if found == None:
-            raise LookupError('No test directory found for test number '
-                              f'{number}!')
-        else:
-            return (found.path, found.name)
+    found = None
+    for entry in dir.iterdir():
+        if entry.is_dir():
+            num = int(entry.name.split('_', maxsplit=1)[0])
+            if number == num:
+                if found:
+                    # duplicate numbers are an error
+                    raise LookupError('Multiple directories found for '
+                                      f'test number {number}: '
+                                      f'{found.name} and {entry.name}')
+                else:
+                    found = entry
+    if found is None:
+        raise LookupError('No test directory found for test number '
+                          f'{number}!')
+    return found, found.name
+
 
 def temp_logfile():
     return tempfile.SpooledTemporaryFile(max_size=4096, mode='w+',
                                          prefix='mod_gnutls', suffix=".log")
 
 
-
-
-def check_ocsp_responder():
+async def check_ocsp_responder():
     # Check if OCSP responder works
     issuer_cert = 'authority/x509.pem'
     check_cert = 'authority/server/x509.pem'
-    command = ['ocsptool', '--ask', '--nonce',
-               '--load-issuer', issuer_cert,
-               '--load-cert', check_cert]
-    return subprocess.run(command).returncode == 0
+    proc = await asyncio.create_subprocess_exec(
+        'ocsptool', '--ask', '--nonce',
+        '--load-issuer', issuer_cert, '--load-cert', check_cert)
+    return (await proc.wait()) == 0
 
-def check_msva():
+
+async def check_msva():
     # Check if MSVA is up
     cert_file = 'authority/client/x509.pem'
     uid_file = 'authority/client/uid'
     with open(uid_file, 'r') as file:
         uid = file.read().strip()
-        command = ['msva-query-agent', 'https', uid, 'x509pem', 'client']
-        with open(cert_file, 'r') as cert:
-            return subprocess.run(command, stdin=cert).returncode == 0
+    with open(cert_file, 'r') as cert:
+        proc = await asyncio.create_subprocess_exec(
+            'msva-query-agent', 'https', uid, 'x509pem', 'client',
+            stdin=cert)
+        return (await proc.wait()) == 0
 
 
-
-def main(args):
+async def main(args):
     # The Automake environment always provides srcdir, the default is
     # for manual use.
-    srcdir = os.path.realpath(os.environ.get('srcdir', '.'))
+    srcdir = Path(os.environ.get('srcdir', '.')).resolve()
     # ensure environment srcdir is absolute
-    os.environ['srcdir'] = srcdir
+    os.environ['srcdir'] = str(srcdir)
 
     # Find the configuration directory for the test in
     # ${srcdir}/tests/, based on the test number.
-    testdir, testname = find_testdir(args.test_number,
-                                     os.path.join(srcdir, 'tests'))
+    testdir, testname = find_testdir(args.test_number, srcdir / 'tests')
     print(f'Found test {testname}, test dir is {testdir}')
     os.environ['TEST_NAME'] = testname
 
     # Load test config
     try:
-        with open(os.path.join(testdir, 'test.yml'), 'r') as conf_file:
+        with open(testdir / 'test.yaml', 'r') as conf_file:
             test_conf = yaml.load(conf_file, Loader=yaml.Loader)
     except FileNotFoundError:
         test_conf = None
 
     # Load test case hooks (if any)
-    plugin_path = os.path.join(testdir, 'hooks.py')
-    plugin = mgstest.hooks.load_hooks_plugin(plugin_path)
+    plugin = mgstest.hooks.load_hooks_plugin(testdir / 'hooks.py')
 
     # PID file name varies depending on whether we're using
     # namespaces.
@@ -121,16 +119,16 @@ def main(args):
 
     valgrind_log = None
     if args.valgrind:
-        valgrind_log = os.path.join('logs', f'valgrind-{testname}.log')
+        valgrind_log = Path('logs', f'valgrind-{testname}.log')
 
     # Define the available services
-    apache = ApacheService(config=os.path.join(testdir, 'apache.conf'),
+    apache = ApacheService(config=testdir / 'apache.conf',
                            pidfile=f'apache2{pidaffix}.pid',
                            valgrind_log=valgrind_log,
                            valgrind_suppress=args.valgrind_suppressions)
-    backend = ApacheService(config=os.path.join(testdir, 'backend.conf'),
+    backend = ApacheService(config=testdir / 'backend.conf',
                             pidfile=f'backend{pidaffix}.pid')
-    ocsp = ApacheService(config=os.path.join(testdir, 'ocsp.conf'),
+    ocsp = ApacheService(config=testdir / 'ocsp.conf',
                          pidfile=f'ocsp{pidaffix}.pid',
                          check=check_ocsp_responder)
     msva = TestService(start=['monkeysphere-validation-agent'],
@@ -162,25 +160,23 @@ def main(args):
         os.environ['MONKEYSPHERE_VALIDATION_AGENT_SOCKET'] = \
             f'http://127.0.0.1:{os.environ["MSVA_PORT"]}'
 
-    with contextlib.ExitStack() as service_stack:
+    async with contextlib.AsyncExitStack() as service_stack:
         if cleanup_callback:
             service_stack.callback(cleanup_callback)
-        service_stack.enter_context(lockfile('test.lock', nolock='MGS_NETNS_ACTIVE' in os.environ))
-        service_stack.enter_context(ocsp.run())
-        service_stack.enter_context(backend.run())
-        service_stack.enter_context(msva.run())
+        if 'MGS_NETNS_ACTIVE' not in os.environ:
+            service_stack.enter_context(lockfile('test.lock'))
 
-        # TEST_SERVICE_MAX_WAIT is in milliseconds
-        wait_timeout = \
-            int(os.environ.get('TEST_SERVICE_MAX_WAIT', 10000)) / 1000
-        for s in bg_services:
-            if s.condition():
-                s.wait_ready(timeout=wait_timeout)
+        wait_timeout = float(os.environ.get('TEST_SERVICE_MAX_WAIT', 10))
+        await asyncio.gather(*(
+            asyncio.create_task(
+                service_stack.enter_async_context(
+                    s.run(ready_timeout=wait_timeout)))
+            for s in bg_services))
 
         # special case: expected to fail in a few cases
-        service_stack.enter_context(apache.run())
-        failed = apache.wait_ready()
-        if os.path.exists(os.path.join(testdir, 'fail.server')):
+        await service_stack.enter_async_context(apache.run())
+        failed = await apache.wait_ready()
+        if (testdir / 'fail.server').is_file():
             if failed:
                 print('Apache server failed to start as expected',
                       file=sys.stderr)
@@ -206,6 +202,10 @@ def main(args):
                           conn_log=args.log_connection,
                           response_log=args.log_responses)
 
+        await asyncio.wait(
+            {asyncio.create_task(s.stop())
+             for s in itertools.chain([apache], bg_services)})
+
     # run extra checks the test's hooks.py might define
     if plugin.post_check:
         args.log_connection.seek(0)
@@ -222,7 +222,6 @@ def main(args):
                 sys.exit(ord('V'))
 
 
-
 if __name__ == "__main__":
     import argparse
     parser = argparse.ArgumentParser(
@@ -253,4 +252,4 @@ if __name__ == "__main__":
     with contextlib.ExitStack() as stack:
         stack.enter_context(contextlib.closing(args.log_connection))
         stack.enter_context(contextlib.closing(args.log_responses))
-        main(args)
+        asyncio.run(main(args))
